{% extends "edc_model_admin/admin/change_list.html" %}
{% load i18n admin_urls static admin_list edc_admin_modify %}

{% block content_title %}<h1>Subject Screening</h1>{% endblock %}

{% block object-tools-items %}
  <li>
    <a href="#" class="changelink">
      Screening to Consent
    </a>
  </li>
  <li>
    <a href="{% url "followup_comm_url" %}" class="changelink">
      Home
    </a>
  </li>
  <li>
    <a href="{% url "intecomm_screening_admin:intecomm_screening_patientlog_changelist" %}" class="changelink">
      Patients
    </a>
  </li>
  <li>
    <a href="{% url "intecomm_screening_admin:intecomm_screening_patientgroup_changelist" %}" class="changelink">
      Groups
    </a>
  </li>
{% endblock %}
