screening_codenames = [
    "intecomm_screening.add_subjectrefusal",
    "intecomm_screening.change_subjectrefusal",
    "intecomm_screening.delete_subjectrefusal",
    "intecomm_screening.add_subjectscreening",
    "intecomm_screening.change_subjectscreening",
    "intecomm_screening.delete_subjectscreening",
    "intecomm_screening.view_historicalsubjectscreening",
    "intecomm_screening.view_historicalsubjectrefusal",
    "intecomm_screening.view_subjectscreening",
    "intecomm_screening.view_subjectrefusal",
]
screening_codenames.sort()
